.. _API:

####################
API Reference Manual
####################

:Release: |version|
:Date: |today|

This guide provides documentation for all modules, function, methods, 
and classes within Py-ART for those in the public API.

Documentation is broken down by directory and module.

.. currentmodule:: pyart

.. autosummary::
   :toctree: generated/
    
   pyart.core
   pyart.io
   pyart.aux_io
   pyart.config
   pyart.correct
   pyart.exceptions
   pyart.retrieve
   pyart.graph
   pyart.filters
   pyart.lazydict
   pyart.map
   pyart.util
   pyart.bridge
   pyart.testing
   pyart._debug_info
